@@ -4,11 +4,10 @@
 
 package Rex::Inventory::DMIDecode::SystemInformation;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.15.0'; # VERSION
 
 use Rex::Inventory::DMIDecode::Section;
 use base qw(Rex::Inventory::DMIDecode::Section);
@@ -33,4 +32,3 @@ sub new {
 }
 
 1;
-
